@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: bmpbuttn.cpp,v 1.32 2006/10/05 19:34:23 MBN Exp $
+// RCS-ID:      $Id: bmpbuttn.cpp 50982 2008-01-01 20:38:33Z VZ $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,10 +12,6 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __VMS
-#define XtScreen XTSCREEN
-#endif
-
 #include "wx/bmpbuttn.h"
 
 #ifdef __VMS__
