@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     20.11.99
-// RCS-ID:      $Id: gdiimage.cpp,v 1.23 2006/10/23 11:58:28 ABX Exp $
+// RCS-ID:      $Id: gdiimage.cpp 45286 2007-04-06 22:19:21Z SN $
 // Copyright:   (c) 1999 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -300,7 +300,7 @@ wxGDIImageHandler* wxGDIImage::FindHandler(
     {
         wxGDIImageHandler*          pHandler = pNode->GetData();
 
-        if ( (pHandler->GetExtension() = rExtension) &&
+        if ( (pHandler->GetExtension() == rExtension) &&
              (lType == -1 || pHandler->GetType() == lType) )
         {
             return pHandler;
