@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     10/10/99
-// RCS-ID:      $Id: menu.cpp,v 1.57 2006/09/04 23:56:47 VZ Exp $
+// RCS-ID:      $Id: menu.cpp 48053 2007-08-13 17:07:01Z JS $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -892,9 +892,19 @@ wxString wxMenuBar::GetLabelTop(
 {
     wxCHECK_MSG( nPos < GetMenuCount(), wxEmptyString,
                  wxT("invalid menu index in wxMenuBar::GetLabelTop") );
-    return m_titles[nPos];
+    return wxStripMenuCodes(m_titles[nPos]);
 } // end of wxMenuBar::GetLabelTop
 
+// Gets the original label at the top-level of the menubar
+wxString wxMenuBar::GetMenuLabel(size_t pos) const
+{
+    wxCHECK_MSG( pos < GetMenuCount(), wxEmptyString,
+                 wxT("invalid menu index in wxMenuBar::GetMenuLabel") );
+
+    return m_titles[pos];
+}
+
+
 // ---------------------------------------------------------------------------
 // wxMenuBar construction
 // ---------------------------------------------------------------------------
