@@ -3,7 +3,7 @@
 // Purpose:     wxString unit test
 // Author:      Vadim Zeitlin, Wlodzimierz ABX Skiba
 // Created:     2004-04-19
-// RCS-ID:      $Id: strings.cpp 45213 2007-04-02 12:25:40Z VS $
+// RCS-ID:      $Id: strings.cpp 58428 2009-01-26 12:59:01Z VZ $
 // Copyright:   (c) 2004 Vadim Zeitlin, Wlodzimierz Skiba
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -47,12 +47,14 @@ private:
         CPPUNIT_TEST( Contains );
         CPPUNIT_TEST( ToLong );
         CPPUNIT_TEST( ToULong );
-#ifdef wxLongLong_t
+#ifdef wxHAS_STRTOLL
         CPPUNIT_TEST( ToLongLong );
         CPPUNIT_TEST( ToULongLong );
-#endif // wxLongLong_t
+#endif // wxHAS_STRTOLL
         CPPUNIT_TEST( ToDouble );
+#if !wxUSE_STL
         CPPUNIT_TEST( WriteBuf );
+#endif //!wxUSE_STL
         CPPUNIT_TEST( CharStr );
     CPPUNIT_TEST_SUITE_END();
 
@@ -71,12 +73,14 @@ private:
     void Contains();
     void ToLong();
     void ToULong();
-#ifdef wxLongLong_t
+#ifdef wxHAS_STRTOLL
     void ToLongLong();
     void ToULongLong();
-#endif // wxLongLong_t
+#endif // wxHAS_STRTOLL
     void ToDouble();
+#if !wxUSE_STL
     void WriteBuf();
+#endif //!wxUSE_STL
     void CharStr();
 
     DECLARE_NO_COPY_CLASS(StringTestCase)
@@ -324,22 +328,6 @@ void StringTestCase::CaseChanges()
     CPPUNIT_ASSERT( s1l == _T("hello!") );
     CPPUNIT_ASSERT( s2u == wxEmptyString );
     CPPUNIT_ASSERT( s2l == wxEmptyString );
-
-#if !wxUSE_UNICODE
-    wxLocale locRu(wxLANGUAGE_RUSSIAN, 0 /* flags */);
-    if ( locRu.IsOk() )
-    {
-        // try upper casing 8bit strings
-        const wchar_t capital_ya[] = { 0x42f, 0 },
-                      small_ya[]   = { 0x44f, 0 };
-
-        wxString sUpper(wxConvLibc.cWC2MB(capital_ya)),
-                 sLower(wxConvLibc.cWC2MB(small_ya));
-
-        CPPUNIT_ASSERT( sUpper.Lower() == sLower );
-        CPPUNIT_ASSERT( sLower.Upper() == sUpper );
-    }
-#endif // !wxUSE_UNICODE
 }
 
 void StringTestCase::Compare()
@@ -535,7 +523,7 @@ void StringTestCase::ToULong()
     }
 }
 
-#ifdef wxLongLong_t
+#ifdef wxHAS_STRTOLL
 
 void StringTestCase::ToLongLong()
 {
@@ -547,9 +535,31 @@ void StringTestCase::ToLongLong()
         if ( ld.flags & (Number_Long | Number_Unsigned) )
             continue;
 
-        CPPUNIT_ASSERT_EQUAL( ld.IsOk(), wxString(ld.str).ToLongLong(&l) );
         if ( ld.IsOk() )
+        {
+            CPPUNIT_ASSERT_MESSAGE
+            (
+                std::string(wxString::Format
+                (
+                    _T("Conversion of \"%s\" to long long failed"),
+                    ld.str
+                ).mb_str()),
+                wxString(ld.str).ToLongLong(&l)
+            );
             CPPUNIT_ASSERT_EQUAL( ld.LLValue(), l );
+        }
+        else
+        {
+            CPPUNIT_ASSERT_MESSAGE
+            (
+                std::string(wxString::Format
+                (
+                    _T("Conversion of \"%s\" to long long succeeded"),
+                    ld.str
+                ).mb_str()),
+                !wxString(ld.str).ToLongLong(&l)
+            );
+        }
     }
 }
 
@@ -563,13 +573,35 @@ void StringTestCase::ToULongLong()
         if ( ld.flags & (Number_Long | Number_Signed) )
             continue;
 
-        CPPUNIT_ASSERT_EQUAL( ld.IsOk(), wxString(ld.str).ToULongLong(&ul) );
         if ( ld.IsOk() )
+        {
+            CPPUNIT_ASSERT_MESSAGE
+            (
+                std::string(wxString::Format
+                (
+                    _T("Conversion of \"%s\" to unsigned long long failed"),
+                    ld.str
+                ).mb_str()),
+                wxString(ld.str).ToULongLong(&ul)
+            );
             CPPUNIT_ASSERT_EQUAL( ld.ULLValue(), ul );
+        }
+        else
+        {
+            CPPUNIT_ASSERT_MESSAGE
+            (
+                std::string(wxString::Format
+                (
+                    _T("Conversion of \"%s\" to unsigned long long succeeded"),
+                    ld.str
+                ).mb_str()),
+                !wxString(ld.str).ToULongLong(&ul)
+            );
+        }
     }
 }
 
-#endif // wxLongLong_t
+#endif // wxHAS_STRTOLL
 
 void StringTestCase::ToDouble()
 {
@@ -607,6 +639,7 @@ void StringTestCase::ToDouble()
     }
 }
 
+#if !wxUSE_STL
 void StringTestCase::WriteBuf()
 {
     wxString s;
@@ -615,7 +648,7 @@ void StringTestCase::WriteBuf()
     CPPUNIT_ASSERT_EQUAL(_T('f'), s[0u]);
     CPPUNIT_ASSERT_EQUAL(_T('o'), s[1]);
     CPPUNIT_ASSERT_EQUAL(_T('o'), s[2]);
-    CPPUNIT_ASSERT_EQUAL(3u, s.length());
+    WX_ASSERT_SIZET_EQUAL(3, s.length());
 
     {
         wxChar *p = s.GetWriteBuf(10);
@@ -626,11 +659,12 @@ void StringTestCase::WriteBuf()
         CPPUNIT_ASSERT_EQUAL(_T('a'), s[1]);
         CPPUNIT_ASSERT_EQUAL(_T('r'), s[2]);
         CPPUNIT_ASSERT_EQUAL(_T('r'), s[3]);
-        CPPUNIT_ASSERT_EQUAL(4u, s.length());
+        WX_ASSERT_SIZET_EQUAL(4, s.length());
 
         CPPUNIT_ASSERT_EQUAL( 0, wxStrcmp(_T("barr"), s) );
     }
 }
+#endif //!wxUSE_STL
 
 
 static bool IsFoo(/* non-const */ char *s)
